Python: module notification

notification (version 0.0.1) | index notification.py

`This tool run scripts and display the result in a Web Interface.
This module adds notifications on WebScripts pages.`

Functions
`` |  | add(environ: os._Environ, user: ~User, server: ~Server, filename: str, arguments: List[str], inputs: List[str], csrf_token: str = None) -> Tuple[str, Dict[str, str], str] `This function adds a new notification in WebScripts pages.`

Data
`` |  | __all__ = ['add'] __annotations__ = {'NEW_LINE': <class 'str'>, 'notification_id': <class 'int'>} __author_email__ = 'mauricelambert434@gmail.com' __copyright__ = '\nWebScripts Copyright (C) 2021, 2022 Maurice L...ome to redistribute it\nunder certain conditions.\n' __description__ = '\nThis tool run scripts and display the result in...s module adds notifications on WebScripts pages.\n' __license__ = 'GPL-3.0 License' __maintainer__ = 'Maurice Lambert' __maintainer_email__ = 'mauricelambert434@gmail.com' __url__ = 'https://github.com/mauricelambert/WebScripts'

Author
`` |  | Maurice Lambert